==> scala-collection-compat_3-2.10.0-javadoc.jar: scripts/searchData.js <==
pages = [{"l":"index.html#","e":false,"i":"","n":"scala-collection-compat","t":"scala-collection-compat","d":"","k":"static"},
{"l":"scala/collection/compat.html#","e":false,"i":"","n":"scala.collection.compat","t":"scala.collection.compat","d":"","k":"package"},
{"l":"scala/collection/compat.html#BuildFrom-0","e":false,"i":"","n":"BuildFrom","t":"BuildFrom[-From, -A, +C] = BuildFrom[From, A, C]","d":"scala.collection.compat","k":"type"},
{"l":"scala/collection/compat.html#BuildFrom-0","e":false,"i":"","n":"BuildFrom","t":"BuildFrom: BuildFrom.type","d":"scala.collection.compat","k":"val"},
{"l":"scala/collection/compat.html#Factory-0","e":false,"i":"","n":"Factory","t":"Factory[-A, +C] = Factory[A, C]","d":"scala.collection.compat","k":"type"},
{"l":"scala/collection/compat.html#Factory-0","e":false,"i":"","n":"Factory","t":"Factory: Factory.type","d":"scala.collection.compat","k":"val"},
{"l":"scala/collection/compat.html#IterableOnce-0","e":false,"i":"","n":"IterableOnce","t":"IterableOnce[+X] = IterableOnce[X]","d":"scala.collection.compat","k":"type"},
{"l":"scala/collection/compat.html#IterableOnce-0","e":false,"i":"","n":"IterableOnce","t":"IterableOnce: IterableOnce.type","d":"scala.collection.compat","k":"val"},
{"l":"scala/collection/compat/immutable.html#","e":false,"i":"","n":"scala.collection.compat.immutable","t":"scala.collection.compat.immutable","d":"","k":"package"},
{"l":"scala/collection/compat/immutable.html#ArraySeq-0","e":false,"i":"","n":"ArraySeq","t":"ArraySeq[+T] = ArraySeq[T]","d":"scala.collection.compat.immutable","k":"type"},
{"l":"scala/collection/compat/immutable.html#ArraySeq-0","e":false,"i":"","n":"ArraySeq","t":"ArraySeq: ArraySeq.type","d":"scala.collection.compat.immutable","k":"val"},
{"l":"scala/collection/compat/immutable.html#LazyList-0","e":false,"i":"","n":"LazyList","t":"LazyList[+T] = LazyList[T]","d":"scala.collection.compat.immutable","k":"type"},
{"l":"scala/collection/compat/immutable.html#LazyList-0","e":false,"i":"","n":"LazyList","t":"LazyList: LazyList.type","d":"scala.collection.compat.immutable","k":"val"},
{"l":"scala/util/control/compat.html#","e":false,"i":"","n":"scala.util.control.compat","t":"scala.util.control.compat","d":"","k":"package"},
{"l":"scala/util/control/compat.html#ControlThrowable-0","e":false,"i":"","n":"ControlThrowable","t":"ControlThrowable = ControlThrowable","d":"scala.util.control.compat","k":"type"}];

==> scala-collection-compat_3-2.12.0-javadoc.jar: scripts/searchData.js <==
pages = [{"l":"index.html#","e":false,"i":"","n":"scala-collection-compat","t":"scala-collection-compat","d":"","k":"static"},
{"l":"scala/collection/compat.html#","e":false,"i":"","n":"scala.collection.compat","t":"scala.collection.compat","d":"","k":"package"},
{"l":"scala/collection/compat.html#BuildFrom-0","e":false,"i":"","n":"BuildFrom","t":"BuildFrom[-From, -A, +C] = BuildFrom[From, A, C]","d":"scala.collection.compat","k":"type"},
{"l":"scala/collection/compat.html#BuildFrom-0","e":false,"i":"","n":"BuildFrom","t":"BuildFrom: BuildFrom.type","d":"scala.collection.compat","k":"val"},
{"l":"scala/collection/compat.html#Factory-0","e":false,"i":"","n":"Factory","t":"Factory[-A, +C] = Factory[A, C]","d":"scala.collection.compat","k":"type"},
{"l":"scala/collection/compat.html#Factory-0","e":false,"i":"","n":"Factory","t":"Factory: Factory.type","d":"scala.collection.compat","k":"val"},
{"l":"scala/collection/compat.html#IterableOnce-0","e":false,"i":"","n":"IterableOnce","t":"IterableOnce[+X] = IterableOnce[X]","d":"scala.collection.compat","k":"type"},
{"l":"scala/collection/compat.html#IterableOnce-0","e":false,"i":"","n":"IterableOnce","t":"IterableOnce: IterableOnce.type","d":"scala.collection.compat","k":"val"},
{"l":"scala/collection/compat/immutable.html#","e":false,"i":"","n":"scala.collection.compat.immutable","t":"scala.collection.compat.immutable","d":"","k":"package"},
{"l":"scala/collection/compat/immutable.html#ArraySeq-0","e":false,"i":"","n":"ArraySeq","t":"ArraySeq[+T] = ArraySeq[T]","d":"scala.collection.compat.immutable","k":"type"},
{"l":"scala/collection/compat/immutable.html#ArraySeq-0","e":false,"i":"","n":"ArraySeq","t":"ArraySeq: ArraySeq.type","d":"scala.collection.compat.immutable","k":"val"},
{"l":"scala/collection/compat/immutable.html#LazyList-0","e":false,"i":"","n":"LazyList","t":"LazyList[+T] = LazyList[T]","d":"scala.collection.compat.immutable","k":"type"},
{"l":"scala/collection/compat/immutable.html#LazyList-0","e":false,"i":"","n":"LazyList","t":"LazyList: LazyList.type","d":"scala.collection.compat.immutable","k":"val"},
{"l":"scala/util/control/compat.html#","e":false,"i":"","n":"scala.util.control.compat","t":"scala.util.control.compat","d":"","k":"package"},
{"l":"scala/util/control/compat.html#ControlThrowable-0","e":false,"i":"","n":"ControlThrowable","t":"ControlThrowable = ControlThrowable","d":"scala.util.control.compat","k":"type"},
{"l":"scala/util/matching/compat.html#","e":false,"i":"","n":"scala.util.matching.compat","t":"scala.util.matching.compat","d":"","k":"package"},
{"l":"scala/util/matching/compat.html#Regex-0","e":false,"i":"","n":"Regex","t":"Regex = Regex","d":"scala.util.matching.compat","k":"type"},
{"l":"scala/util/matching/compat.html#Regex-0","e":false,"i":"","n":"Regex","t":"Regex: Regex.type","d":"scala.util.matching.compat","k":"val"}];
